@@ -9,5 +9,7 @@ fn main() {
 
 fn my_panic(_: &PanicInfo) -> ! {
     eprintln!("a cool panic");
-    loop { std::thread::sleep(std::time::Duration::from_secs(5)); }
+    loop {
+        std::thread::sleep(std::time::Duration::from_secs(5));
+    }
 }
